"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chunk import Chunk, ChunkTypedDict
from .document import Document, DocumentTypedDict
from duckyai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class RetrieveDocumentsResponseTypedDict(TypedDict):
    documents: List[DocumentTypedDict]
    chunks: List[ChunkTypedDict]


class RetrieveDocumentsResponse(BaseModel):
    documents: List[Document]

    chunks: List[Chunk]
