"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from duckyai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IndexTypedDict(TypedDict):
    index_id: str
    r"""The unique identifier of the index"""
    index_name: str
    r"""The name of the index"""
    record_count: int
    r"""The number of records in the index"""
    status: NotRequired[str]
    r"""The status of the index"""


class Index(BaseModel):
    index_id: str
    r"""The unique identifier of the index"""

    index_name: str
    r"""The name of the index"""

    record_count: int
    r"""The number of records in the index"""

    status: Optional[str] = None
    r"""The status of the index"""
