"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from duckyai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DocumentRetrievedResponseTypedDict(TypedDict):
    document: NotRequired[DocumentTypedDict]


class DocumentRetrievedResponse(BaseModel):
    document: Optional[Document] = None
