"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from duckyai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CreateIndexResponseTypedDict(TypedDict):
    index_id: NotRequired[str]
    r"""The ID of the created index"""


class CreateIndexResponse(BaseModel):
    index_id: Optional[str] = None
    r"""The ID of the created index"""
