"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .index import Index, IndexTypedDict
from duckyai.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ListIndexesResponseTypedDict(TypedDict):
    indexes: NotRequired[List[IndexTypedDict]]
    r"""List of all indexes"""


class ListIndexesResponse(BaseModel):
    indexes: Optional[List[Index]] = None
    r"""List of all indexes"""
