"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from duckyai.types import BaseModel
from duckyai.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class DeleteIndexRequestTypedDict(TypedDict):
    index_name: str
    r"""The name of the index to be deleted"""


class DeleteIndexRequest(BaseModel):
    index_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The name of the index to be deleted"""
