"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from duckyai.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ChunkTypedDict(TypedDict):
    chunk_id: str
    r"""The ID of the chunk"""
    content: str
    r"""The content of the chunk"""
    doc_id: str
    r"""The ID of the document the chunk belongs to"""
    metadata: NotRequired[Dict[str, Any]]
    r"""Metadata associated with the document. Accepts key value pairs where the value can be a string, number, boolean, or list of strings."""


class Chunk(BaseModel):
    chunk_id: str
    r"""The ID of the chunk"""

    content: str
    r"""The content of the chunk"""

    doc_id: str
    r"""The ID of the document the chunk belongs to"""

    metadata: Optional[Dict[str, Any]] = None
    r"""Metadata associated with the document. Accepts key value pairs where the value can be a string, number, boolean, or list of strings."""
