"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from duckyai.types import BaseModel
from duckyai.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class DeleteDocumentRequestTypedDict(TypedDict):
    doc_id: str
    r"""The unique ID of the document to delete"""
    index_name: str
    r"""The name of the index containing the document"""


class DeleteDocumentRequest(BaseModel):
    doc_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The unique ID of the document to delete"""

    index_name: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""The name of the index containing the document"""
