"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from duckyai.types import BaseModel
from typing_extensions import TypedDict


class CreateIndexRequestTypedDict(TypedDict):
    index_name: str
    r"""The name of the index"""


class CreateIndexRequest(BaseModel):
    index_name: str
    r"""The name of the index"""
